@@ -11,7 +11,7 @@ our @ISA = qw{ Exporter };
 use Carp;
 use Test::More 0.88;
 
-our $VERSION = '0.009';
+our $VERSION = '0.010';
 
 our %EXPORT_TAGS = (
     const	=> [ qw{ IS_WINDOWS } ],
@@ -154,7 +154,6 @@ This class supports the following public methods:
 
 This class has the following attributes:
 
-
 =head1 SEE ALSO
 
 <<< replace or remove boilerplate >>>
@@ -162,7 +161,8 @@ This class has the following attributes:
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<https://rt.cpan.org>, or in electronic mail to the author.
+L<https://github.com/trwyant/perl-Win32API-File-Time/issues>, or in
+electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -170,7 +170,7 @@ Tom Wyant (wyant at cpan dot org)
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2016-2017, 2019 by Thomas R. Wyant, III
+Copyright (C) 2016-2017, 2019-2021 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
